"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
class ServerlessPlugin {
    apply(compiler) {
        compiler.hooks.compilation.tap("ServerlessPlugin", (compilation)=>{
            const hook = compilation.hooks.optimizeChunks;
            hook.tap("ServerlessPlugin", (chunks)=>{
                for (const chunk of chunks){
                    // If chunk is not an entry point skip them
                    if (compilation.chunkGraph.getNumberOfEntryModules(chunk) === 0) {
                        continue;
                    }
                    // Async chunks are usages of import() for example
                    const dynamicChunks = chunk.getAllAsyncChunks();
                    for (const dynamicChunk of dynamicChunks){
                        for (const module of compilation.chunkGraph.getChunkModulesIterable(dynamicChunk)){
                            // Add module back into the entry chunk
                            if (!compilation.chunkGraph.isModuleInChunk(module, chunk)) {
                                compilation.chunkGraph.connectChunkAndModule(chunk, module);
                            }
                        }
                    }
                }
            });
        });
    }
}
exports.ServerlessPlugin = ServerlessPlugin;

//# sourceMappingURL=serverless-plugin.js.map